# # Install logitr package from github
# devtools::install_github('jhelvy/logitr')

# Load logitr package
library('logitr')

# ============================================================================
# Estimate homogeneous MNL models

# Run a MNL model in the Preference Space:
mnl_pref <- logitr(
  data   = yogurt,
  choice = 'choice',
  obsID  = 'obsID',
  pars   = c('price', 'feat', 'brand')
)

# Print a summary of the results:
summary(mnl_pref)

# Get the coefficients from the model:
coef(mnl_pref)

# Get the WTP implied from the preference space model
wtp_mnl_pref <- wtp(mnl_pref, price = 'price')
wtp_mnl_pref

# Run a MNL model in the WTP Space using a multistart:
mnl_wtp <- logitr(
  data       = yogurt,
  choice     = 'choice',
  obsID      = 'obsID',
  pars       = c('feat', 'brand'),
  price      = 'price',
  modelSpace = 'wtp',
  # Since WTP space models are non-convex, run a multistart:
  numMultiStarts = 10,
  # Use the computed WTP from the preference space model as the starting
  # values for the first run:
  startVals = wtp_mnl_pref$Estimate
)

# Print a summary of all multistart runs and a summary of the best model:
summary(mnl_wtp)

# Get the coefficients from the model:
coef(mnl_wtp)

# CHECKING FOR LOCAL MINIMA IN WTP SPACE MODELS:
# Comparing the WTP and log-likelihood values between the equivalent models in
# the preference space and WTP space is a helpful check for whether you have
# reached a global solution in WTP space models, which have non-convex
# log-likelihoods functions. This can be done using the wtpCompare function:
wtpCompare(mnl_pref, mnl_wtp, price = 'price')

# Save results
saveRDS(mnl_pref, here::here('inst', 'extdata', 'mnl_pref.Rds'))
saveRDS(mnl_wtp,  here::here('inst', 'extdata', 'mnl_wtp.Rds'))
